@@ -153,6 +153,26 @@ class Client(ClientWithProject):
         """
         return self._batch_stack.pop()
 
+    def _bucket_arg_to_bucket(self, bucket_or_name):
+        """Helper to return given bucket or create new by name.
+
+        Args:
+            bucket_or_name (Union[ \
+                :class:`~google.cloud.storage.bucket.Bucket`, \
+                 str, \
+            ]):
+                The bucket resource to pass or name to create.
+
+        Returns:
+            google.cloud.storage.bucket.Bucket
+                The newly created bucket or the given one.
+        """
+        if isinstance(bucket_or_name, Bucket):
+            bucket = bucket_or_name
+        else:
+            bucket = Bucket(self, name=bucket_or_name)
+        return bucket
+
     @property
     def current_batch(self):
         """Currently-active batch.
@@ -252,12 +272,7 @@ class Client(ClientWithProject):
             >>> bucket = client.get_bucket(bucket)  # API request.
 
         """
-
-        bucket = None
-        if isinstance(bucket_or_name, Bucket):
-            bucket = bucket_or_name
-        else:
-            bucket = Bucket(self, name=bucket_or_name)
+        bucket = self._bucket_arg_to_bucket(bucket_or_name)
 
         bucket.reload(client=self)
         return bucket
@@ -299,7 +314,7 @@ class Client(ClientWithProject):
                 Optional. Whether requester pays for API requests for this
                 bucket and its blobs.
             project (str):
-                Optional. the project under which the  bucket is to be created.
+                Optional. the project under which the bucket is to be created.
                 If not passed, uses the project set on the client.
 
         Returns:
@@ -331,12 +346,7 @@ class Client(ClientWithProject):
             >>> bucket = client.create_bucket(bucket)  # API request.
 
         """
-
-        bucket = None
-        if isinstance(bucket_or_name, Bucket):
-            bucket = bucket_or_name
-        else:
-            bucket = Bucket(self, name=bucket_or_name)
+        bucket = self._bucket_arg_to_bucket(bucket_or_name)
 
         if requester_pays is not None:
             bucket.requester_pays = requester_pays
@@ -379,7 +389,7 @@ class Client(ClientWithProject):
 
             >>> with open('file-to-download-to') as file_obj:
             >>>     client.download_blob_to_file(
-            >>>         'gs://bucket_name/path/to/blob', file)
+            >>>         'gs://bucket_name/path/to/blob', file_obj)
 
 
         """
@@ -390,10 +400,84 @@ class Client(ClientWithProject):
             if scheme != "gs":
                 raise ValueError("URI scheme must be gs")
             bucket = Bucket(self, name=netloc)
-            blob_or_uri = Blob(path, bucket)
+            blob_or_uri = Blob(path[1:], bucket)
 
             blob_or_uri.download_to_file(file_obj, client=self, start=start, end=end)
 
+    def list_blobs(
+        self,
+        bucket_or_name,
+        max_results=None,
+        page_token=None,
+        prefix=None,
+        delimiter=None,
+        versions=None,
+        projection="noAcl",
+        fields=None,
+    ):
+        """Return an iterator used to find blobs in the bucket.
+
+        If :attr:`user_project` is set, bills the API request to that project.
+
+        Args:
+            bucket_or_name (Union[ \
+                :class:`~google.cloud.storage.bucket.Bucket`, \
+                 str, \
+            ]):
+                The bucket resource to pass or name to create.
+
+            max_results (int):
+                (Optional) The maximum number of blobs in each page of results
+                from this request. Non-positive values are ignored. Defaults to
+                a sensible value set by the API.
+
+            page_token (str):
+                (Optional) If present, return the next batch of blobs, using the
+                value, which must correspond to the ``nextPageToken`` value
+                returned in the previous response.  Deprecated: use the ``pages``
+                property of the returned iterator instead of manually passing the
+                token.
+
+            prefix (str):
+                (Optional) prefix used to filter blobs.
+
+            delimiter (str):
+                (Optional) Delimiter, used with ``prefix`` to
+                emulate hierarchy.
+
+            versions (bool):
+                (Optional) Whether object versions should be returned
+                as separate blobs.
+
+            projection (str):
+                (Optional) If used, must be 'full' or 'noAcl'.
+                Defaults to ``'noAcl'``. Specifies the set of
+                properties to return.
+
+            fields (str):
+                (Optional) Selector specifying which fields to include
+                in a partial response. Must be a list of fields. For
+                example to get a partial response with just the next
+                page token and the name and language of each blob returned:
+                ``'items(name,contentLanguage),nextPageToken'``.
+                See: https://cloud.google.com/storage/docs/json_api/v1/parameters#fields
+
+        Returns:
+            Iterator of all :class:`~google.cloud.storage.blob.Blob`
+            in this bucket matching the arguments.
+        """
+        bucket = self._bucket_arg_to_bucket(bucket_or_name)
+        return bucket.list_blobs(
+            max_results=max_results,
+            page_token=page_token,
+            prefix=prefix,
+            delimiter=delimiter,
+            versions=versions,
+            projection=projection,
+            fields=fields,
+            client=self
+        )
+
     def list_buckets(
         self,
         max_results=None,
